@@ -10,9 +10,11 @@ from .models import (
     ContextMessageRole,
     Message,
     ContextMessage,
-    ContextMessageWithImage,
     LLMInput,
-    LLMInputWithImage,
+    LLMOutput,
+    build_messages,
+    stream_generate,
+    timing_context,
 )
 from .utils import StorageDir, download
 
@@ -24,9 +26,11 @@ __all__ = [
     "ContextMessageRole",
     "Message",
     "ContextMessage",
-    "ContextMessageWithImage",
     "LLMInput",
-    "LLMInputWithImage",
+    "LLMOutput",
+    "build_messages",
+    "stream_generate",
+    "timing_context",
     "StorageDir",
     "download",
 ]
\ No newline at end of file
